@@ -1,9 +1,10 @@
 /* functions to handle zlib-compressed data read from socket
 */
+#include <stdio.h>//essai
+#include <stdlib.h>//essai
 #include <zlib.h>
 #include <unistd.h>
-#include <stdlib.h>
-#include <stdio.h>
+//#include <stdio.h>
 #include <string.h>
 #ifdef WIN32
 #include <winsock.h>
