@@ -179,12 +179,20 @@ char *mac_GetOutputFName_Plus(const char *dfault, const char *message, int use_o
 //run panel  
   NSWindow *key = [NSApp keyWindow];
   int retval;
+#if MAC_OS_X_VERSION_MAX_ALLOWED >= 1060 // MAC_OS_X_VERSION_10_6
   if (fl_mac_os_version >= 100600) {
-    if (dir) [_panel performSelector:@selector(setDirectoryURL:) withObject:[NSURL fileURLWithPath:dir]];
-    if (fname) [_panel performSelector:@selector(setNameFieldStringValue:) withObject:fname];
-    retval = [_panel runModal];
+    if (dir) [_panel setDirectoryURL:[NSURL fileURLWithPath:dir]];
+    if (fname) [_panel setNameFieldStringValue:fname];
+    __block NSInteger complete = -1;
+    [_panel beginSheetModalForWindow:key completionHandler:^(NSInteger returnCode) {
+        complete = returnCode; // this block runs after OK or Cancel was triggered in file dialog
+    }]; // this message returns immediately and begins the file dialog as a sheet
+    while (complete < 0) Fl::wait(100); // loop until end of file dialog
+    retval = complete;
   }
-  else {
+  else
+#endif
+  {
     retval = [(id)_panel runModalForDirectory:dir file:fname];
   }
   [key makeKeyWindow];
