@@ -364,9 +364,10 @@ void geni_act(SEA_VIEW *view)
   int i, j, k, l, ii, nb, lgtot, lg, lgvar, lginfo, *lgcomp, totlgcomp, nc=0;
   int *selected, nbaa, nbcp;
   double **comp, *compall, compcomp[4], **compgroup, *compgroupall, min[4], max[4];
-  double P, Psum=0., Q, Qsum=0., Pmin, Pmax, Qmin, Qmax, titvratio, titvmin, titvmax, freq[16], mat_obs[16], *ti, *tv;
+  double P, Psum=0., Q, Qsum=0., Pmin=0, Pmax=0, Qmin=0, Qmax=0, titvratio, titvmin, titvmax, freq[16], mat_obs[16], *ti, *tv;
   char **genseq, **genname, *text, *minname[4], *maxname[4], nt[4]={'A', 'C', 'G', 'T'};
-  char *titvminname1, *titvminname2, *titvmaxname1, *titvmaxname2;
+  const char *titvminname1 = "", *titvminname2 = "";
+  const char *titvmaxname1 = "", *titvmaxname2 = "";
   int lgseq = view->seq_length;
   int nbseq = view->tot_seqs;
   
@@ -639,10 +640,11 @@ void geni_act(SEA_VIEW *view)
   
   if(!view->protein && nb>1 && lg!=0){
     sprintf(p, "\nOBSERVED CHANGES (complete sites)\n"); p += strlen(p);
+    double PQratio = Qsum ? (double)Psum/Qsum : 0;
     if(nb>2)
-      sprintf(p, "Transition/transversion ratio : %.3f (mean over all sequence pairs)\n", (double)Psum/Qsum);
+      sprintf(p, "Transition/transversion ratio : %.3f (mean over all sequence pairs)\n", PQratio);
     else
-      sprintf(p, "Transition/transversion ratio : %.3f\n", (double)Psum/Qsum);
+      sprintf(p, "Transition/transversion ratio : %.3f\n", PQratio);
     p += strlen(p);
     if(nb>2){
       sprintf(p, "Minimum : %.3f (%s - %s, %d transitions, %d transversions)\n", titvmin, titvminname1, titvminname2, (int)Pmin, (int)Qmin);
