@@ -221,7 +221,7 @@ void svg_tree_dialog_and_save(FD_nj_plot *fd_nj_plot)
 {
   Fl_Native_File_Chooser *chooser = new Fl_Native_File_Chooser(Fl_Native_File_Chooser::BROWSE_SAVE_FILE);
   chooser->title("Enter SVG filename");       
-  chooser->filter("SVG Files\t*.{svg}");
+  chooser->filter("SVG Files\t*.svg");
   char tmp[100];
   strcpy(tmp, extract_filename(fd_nj_plot->tree_name));
   char *p = strrchr(tmp, '.'); if(p != NULL) *p = 0;
