@@ -1017,9 +1017,10 @@ int copyfile(const char *to, const char *from)
 void save_svg_file_callback(Fl_Widget *ob, void *data) {
   SVG_View_data* svg_data = (SVG_View_data*)data;
 
-  Fl_Native_File_Chooser* chooser = new Fl_Native_File_Chooser();
+  Fl_Native_File_Chooser* chooser = new Fl_Native_File_Chooser(Fl_Native_File_Chooser::BROWSE_SAVE_FILE);
   chooser->title("Save file");
-  chooser->type(Fl_Native_File_Chooser::BROWSE_SAVE_FILE);
+  chooser->options(Fl_Native_File_Chooser::USE_FILTER_EXT | chooser->options());
+  chooser->filter("SVG files\t*.svg");
   const char* filename = run_and_close_native_file_chooser(chooser);
 
   if(filename != NULL and strcmp(filename, "") != 0) {
