@@ -460,7 +460,8 @@ void print_unrooted(FD_unrooted *fd_unrooted, const char *name, bool to_ps_file,
   if (to_ps_file) ((Fl_PDF_File_Device*)myprinter)->surface_try(&jbuf);
   if ( (!to_ps_file) || setjmp(*jbuf) == 0) { // replaces PDF_TRY
 #endif    
-    myprinter->start_page();
+    if (to_ps_file) ((Fl_PDF_or_PS_File_Device*)myprinter)->start_page();
+    else myprinter->start_page();
     fd_unrooted->previous_w = fd_unrooted->previous_h = 0;
     myprinter->printable_rect( &fd_unrooted->w, &fd_unrooted->h);
     fd_unrooted->x = fd_unrooted->y = 0;
