@@ -356,7 +356,7 @@ int read_fasta_align(const char *fname, char ***pseq, char ***pseqname,
 {
 FILE *in;
 int totseqs, lseq, l2, l, lenseqs;
-char line[300], *p, *i, c, *q, *r;
+char line[500], *p, *i, c, *q, *r;
 static char ret_message[200];
 char **seq, **seqname, **comments, *tmpseq = NULL;
 
@@ -400,11 +400,11 @@ while( i != NULL ){
 	p = line + 1; 
   while (*p == ' ') p++;
 	if(spaces_in_names) {
-	  while(*p != '\n') p++;
+	  while(*p && *p != '\n') p++;
 	  while(*(p-1) == ' ') p--;
 	  }
 	else {
-	  while(*p != ' ' && *p != '\n') p++;
+	  while(*p && *p != ' ' && *p != '\n') p++;
 	  }
   r = line + 1;
   while (*r == ' ') r++;
@@ -1631,9 +1631,7 @@ Fl_Native_File_Chooser *chooser = new Fl_Native_File_Chooser();
 
 chooser->type(Fl_Native_File_Chooser::BROWSE_SAVE_FILE);   
 chooser->options(Fl_Native_File_Chooser::SAVEAS_CONFIRM | chooser->options());
-#if SEAVIEW_FLTK_VERSION >= 133 || defined(__APPLE__)
 chooser->options(Fl_Native_File_Chooser::USE_FILTER_EXT | chooser->options());
-#endif
 chooser->title(message);  
 chooser->directory(extract_dirname(fname)); 
 chooser->preset_file(extract_filename(fname)); 
